summaryrefslogtreecommitdiff
path: root/django/template
diff options
context:
space:
mode:
authorMike Hansen <mike@rover.com>2019-09-23 08:31:21 -0700
committerMariusz Felisiak <felisiak.mariusz@gmail.com>2019-12-18 13:15:38 +0100
commit35d36d946272bed06a3d7c7cd4e5b71b613e7a4f (patch)
treee6c774f841dc77ca311be6ecfad9c5d7ef790336 /django/template
parentd291c72bf24387e4abe8d9883ebe9c69abdd26d0 (diff)
Refs #30585 -- Updated project templates and tests to use (block)translate tags.
Diffstat (limited to 'django/template')
-rw-r--r--django/template/defaulttags.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/django/template/defaulttags.py b/django/template/defaulttags.py
index d010bc7560..7ab21b320e 100644
--- a/django/template/defaulttags.py
+++ b/django/template/defaulttags.py
@@ -1418,10 +1418,10 @@ def widthratio(parser, token):
(because 175/200 = .875; .875 * 100 = 87.5 which is rounded up to 88).
In some cases you might want to capture the result of widthratio in a
variable. It can be useful for instance in a blocktrans like this::
{% widthratio this_value max_value max_width as width %}
- {% blocktrans %}The width is: {{ width }}{% endblocktrans %}
+ {% blocktranslate %}The width is: {{ width }}{% endblocktranslate %}
"""
bits = token.split_contents()
if len(bits) == 4:
@@ -1418,10 +1418,10 @@ def widthratio(parser, token):
(because 175/200 = .875; .875 * 100 = 87.5 which is rounded up to 88).
In some cases you might want to capture the result of widthratio in a
- variable. It can be useful for instance in a blocktrans like this::
+ variable. It can be useful for instance in a blocktranslate like this::
{% widthratio this_value max_value max_width as width %}